==> mx-service-manager_23.9.02.tar.xz: mx-service-manager-23.9.02/translations/mx-service-manager_ca.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ca">
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.ui" line="14"/>
        <location filename="../mainwindow.cpp" line="292"/>
        <source>MX Service Manager</source>
        <translation>MX Service Manager</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="62"/>
        <source>About this application</source>
        <translation>Quant a aquest programa</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="26"/>
        <location filename="../mainwindow.cpp" line="142"/>
        <location filename="../mainwindow.cpp" line="307"/>
        <source>&amp;Enable at boot</source>
        <translation>&amp;Activa en arrencar</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="65"/>
        <source>&amp;About...</source>
        <translation>Quant &amp;a...</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="72"/>
        <source>Alt+B</source>
        <translation>Alt+B</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="126"/>
        <source>Display help </source>
        <translation>Mostra l&apos;ajuda</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="129"/>
        <source>&amp;Help</source>
        <translation>&amp;Ajuda</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="171"/>
        <source>&amp;Close</source>
        <translation>Tan&amp;ca </translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="227"/>
        <location filename="../mainwindow.cpp" line="264"/>
        <source>Services enabled at boot</source>
        <translation>Serveis activats en engegar</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="232"/>
        <location filename="../mainwindow.cpp" line="265"/>
        <source>Services disabled at boot</source>
        <translation>Serveis desactivats en engegar</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="253"/>
        <source>search</source>
        <translation>cerca</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="203"/>
        <location filename="../mainwindow.cpp" line="124"/>
        <source>&amp;Stop</source>
        <translation>A&amp;tura</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="282"/>
        <source>This tool lists services and daemons (processes that run in the background) found on this system. Be careful to avoid stopping something that might disrupt a critical component; best to leave it alone if you don&apos;t know what it is.</source>
        <translation>Aquesta eina llista els serveis i els dimonis (processos que s&apos;executen en segon pla) que es troben al sistema. Tingueu compte de no aturar quelcom que trencar un component crític; millor deixar-lo si no sabeu el que és.</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="217"/>
        <source>All services</source>
        <translation>Tots els serveis</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="222"/>
        <location filename="../mainwindow.cpp" line="259"/>
        <source>Running services</source>
        <translation>Serveis executant-se</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="136"/>
        <source>Alt+H</source>
        <translation>Alt+H</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="168"/>
        <source>Quit application</source>
        <translation>Surt de l&apos;aplicació</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="178"/>
        <source>Alt+N</source>
        <translation>Alt+N</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="263"/>
        <location filename="../mainwindow.cpp" line="66"/>
        <location filename="../mainwindow.cpp" line="79"/>
        <source>Loading...</source>
        <translation>Carregant...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="60"/>
        <location filename="../mainwindow.cpp" line="309"/>
        <location filename="../mainwindow.cpp" line="316"/>
        <location filename="../mainwindow.cpp" line="338"/>
        <location filename="../mainwindow.cpp" line="347"/>
        <source>Error</source>
        <translation>Error</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="61"/>
        <source>Could not determine the init system. This program is supposed to run either with systemd or sysvinit</source>
        <translation>No puc determinar el sistema d&apos;inici. Es suposa que el programa es pot executar tant en systemd com en sysvinit</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="129"/>
        <location filename="../mainwindow.cpp" line="336"/>
        <source>S&amp;tart</source>
        <translation>I&amp;nici</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="135"/>
        <source>&amp;Disable at boot</source>
        <translation>&amp;Desactiva en arrencar</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="275"/>
        <source>%1 total services, %2 currently %3running%4</source>
        <translation>%1 serveis en total, %2 actualment %3executant-se%4</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="279"/>
        <source>%1 %2enabled%3 at boot, but not running</source>
        <translation>%1 %2activats%3 a l&apos;arrancala, però no executant-se</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="292"/>
        <source>About %1</source>
        <translation>Quant a %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="293"/>
        <source>Version: </source>
        <translation>Versió: </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="294"/>
        <source>Service and daemon manager</source>
        <translation>Gestor de Serveis i Dimonis</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="296"/>
        <source>Copyright (c) MX Linux</source>
        <translation>Copyright (c) MX Linux</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="297"/>
        <source>%1 License</source>
        <translation>Llicència de %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="309"/>
        <source>Could not enable %1</source>
        <translation>No puc activar %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="313"/>
        <location filename="../mainwindow.cpp" line="320"/>
        <location filename="../mainwindow.cpp" line="343"/>
        <location filename="../mainwindow.cpp" line="352"/>
        <source>Success</source>
        <translation>Èxit</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="313"/>
        <source>%1 was enabled at boot time.</source>
        <translation>%1 s&apos;ha activat en arrencar.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="316"/>
        <source>Could not disable %1</source>
        <translation>No puc desactivar %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="320"/>
        <source>%1 was disabled.</source>
        <translation>S&apos;ha desactivat %1 </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="328"/>
        <source>%1 Help</source>
        <translation>Ajuda de %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="338"/>
        <source>Could not start %1</source>
        <translation>No puc arrencar %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="343"/>
        <source>%1 was started.</source>
        <translation>S&apos;ha iniciat %1.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="347"/>
        <source>Could not stop %1</source>
        <translation>No puc aturar %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="352"/>
        <source>%1 was stopped.</source>
        <translation>S&apos;ha aturat %1.</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../about.cpp" line="51"/>
        <source>License</source>
        <translation>Llicència</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="52"/>
        <location filename="../about.cpp" line="62"/>
        <source>Changelog</source>
        <translation>Registre de canvis</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="53"/>
        <source>Cancel</source>
        <translation>Cancel·la</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="75"/>
        <source>&amp;Close</source>
        <translation>Tan&amp;ca </translation>
    </message>
    <message>
        <location filename="../main.cpp" line="74"/>
        <source>Error</source>
        <translation>Error</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="75"/>
        <source>You seem to be logged in as root, please log out and log in as normal user to use this program.</source>
        <translation>Sembla que esteu connectat com a administrador, si us plau sortiu i connecteu-vos com a usuari normal per a usar aquest programa.</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="81"/>
        <source>version:</source>
        <translation>versió:</translation>
    </message>
</context>
</TS>

==> mx-service-manager_24.3.02.orig.tar.xz: mx-service-manager-24.3.02/translations/mx-service-manager_ca.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ca">
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.ui" line="14"/>
        <location filename="../mainwindow.cpp" line="302"/>
        <location filename="../ui_mainwindow.h" line="225"/>
        <source>MX Service Manager</source>
        <translation>MX Service Manager</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="26"/>
        <location filename="../mainwindow.cpp" line="157"/>
        <location filename="../mainwindow.cpp" line="317"/>
        <location filename="../ui_mainwindow.h" line="226"/>
        <source>&amp;Enable at boot</source>
        <translation>&amp;Activa en arrencar</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="62"/>
        <location filename="../ui_mainwindow.h" line="228"/>
        <source>About this application</source>
        <translation>Quant a aquest programa</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="65"/>
        <location filename="../ui_mainwindow.h" line="230"/>
        <source>&amp;About...</source>
        <translation>Quant &amp;a...</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="72"/>
        <location filename="../ui_mainwindow.h" line="232"/>
        <source>Alt+B</source>
        <translation>Alt+B</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="126"/>
        <location filename="../ui_mainwindow.h" line="236"/>
        <source>Display help </source>
        <translation>Mostra l&apos;ajuda</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="129"/>
        <location filename="../ui_mainwindow.h" line="238"/>
        <source>&amp;Help</source>
        <translation>&amp;Ajuda</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="136"/>
        <location filename="../ui_mainwindow.h" line="240"/>
        <source>Alt+H</source>
        <translation>Alt+H</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="168"/>
        <location filename="../ui_mainwindow.h" line="243"/>
        <source>Quit application</source>
        <translation>Surt de l&apos;aplicació</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="171"/>
        <location filename="../ui_mainwindow.h" line="245"/>
        <source>&amp;Close</source>
        <translation>Tan&amp;ca </translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="178"/>
        <location filename="../ui_mainwindow.h" line="247"/>
        <source>Alt+N</source>
        <translation>Alt+N</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="203"/>
        <location filename="../mainwindow.cpp" line="139"/>
        <location filename="../ui_mainwindow.h" line="250"/>
        <source>&amp;Stop</source>
        <translation>A&amp;tura</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="217"/>
        <location filename="../ui_mainwindow.h" line="251"/>
        <source>All services</source>
        <translation>Tots els serveis</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="222"/>
        <location filename="../mainwindow.cpp" line="277"/>
        <location filename="../ui_mainwindow.h" line="252"/>
        <source>Running services</source>
        <translation>Serveis executant-se</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="227"/>
        <location filename="../mainwindow.cpp" line="278"/>
        <location filename="../ui_mainwindow.h" line="253"/>
        <source>Services enabled at boot</source>
        <translation>Serveis activats en engegar</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="232"/>
        <location filename="../mainwindow.cpp" line="279"/>
        <location filename="../ui_mainwindow.h" line="254"/>
        <source>Services disabled at boot</source>
        <translation>Serveis desactivats en engegar</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="268"/>
        <location filename="../ui_mainwindow.h" line="257"/>
        <source>search</source>
        <translation>cerca</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="278"/>
        <location filename="../mainwindow.cpp" line="68"/>
        <location filename="../mainwindow.cpp" line="81"/>
        <location filename="../ui_mainwindow.h" line="258"/>
        <source>Loading...</source>
        <translation>Carregant...</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="297"/>
        <location filename="../ui_mainwindow.h" line="259"/>
        <source>This tool lists services and daemons (processes that run in the background) found on this system. Be careful to avoid stopping something that might disrupt a critical component; best to leave it alone if you don&apos;t know what it is.</source>
        <translation>Aquesta eina llista els serveis i els dimonis (processos que s&apos;executen en segon pla) que es troben al sistema. Tingueu compte de no aturar quelcom que trencar un component crític; millor deixar-lo si no sabeu el que és.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="62"/>
        <location filename="../mainwindow.cpp" line="319"/>
        <location filename="../mainwindow.cpp" line="326"/>
        <location filename="../mainwindow.cpp" line="347"/>
        <location filename="../mainwindow.cpp" line="356"/>
        <source>Error</source>
        <translation>Error</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="63"/>
        <source>Could not determine the init system. This program is supposed to run either with systemd or sysvinit</source>
        <translation>No puc determinar el sistema d&apos;inici. Es suposa que el programa es pot executar tant en systemd com en sysvinit</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="144"/>
        <location filename="../mainwindow.cpp" line="345"/>
        <source>S&amp;tart</source>
        <translation>I&amp;nici</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="150"/>
        <source>&amp;Disable at boot</source>
        <translation>&amp;Desactiva en arrencar</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="286"/>
        <source>%1 total services, %2 currently &lt;font color=&apos;%3&apos;&gt;running&lt;/font&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="288"/>
        <source>%1 &lt;font color=&apos;%2&apos;&gt;enabled&lt;/font&gt; at boot, but not running</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="302"/>
        <source>About %1</source>
        <translation>Quant a %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="303"/>
        <source>Version: </source>
        <translation>Versió: </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="304"/>
        <source>Service and daemon manager</source>
        <translation>Gestor de Serveis i Dimonis</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="306"/>
        <source>Copyright (c) MX Linux</source>
        <translation>Copyright (c) MX Linux</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="307"/>
        <source>%1 License</source>
        <translation>Llicència de %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="319"/>
        <source>Could not enable %1</source>
        <translation>No puc activar %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="323"/>
        <location filename="../mainwindow.cpp" line="330"/>
        <location filename="../mainwindow.cpp" line="352"/>
        <location filename="../mainwindow.cpp" line="361"/>
        <source>Success</source>
        <translation>Èxit</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="323"/>
        <source>%1 was enabled at boot time.</source>
        <translation>%1 s&apos;ha activat en arrencar.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="326"/>
        <source>Could not disable %1</source>
        <translation>No puc desactivar %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="330"/>
        <source>%1 was disabled.</source>
        <translation>S&apos;ha desactivat %1 </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="337"/>
        <source>%1 Help</source>
        <translation>Ajuda de %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="347"/>
        <source>Could not start %1</source>
        <translation>No puc arrencar %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="352"/>
        <source>%1 was started.</source>
        <translation>S&apos;ha iniciat %1.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="356"/>
        <source>Could not stop %1</source>
        <translation>No puc aturar %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="361"/>
        <source>%1 was stopped.</source>
        <translation>S&apos;ha aturat %1.</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../about.cpp" line="70"/>
        <source>License</source>
        <translation>Llicència</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="71"/>
        <location filename="../about.cpp" line="81"/>
        <source>Changelog</source>
        <translation>Registre de canvis</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="72"/>
        <source>Cancel</source>
        <translation>Cancel·la</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="94"/>
        <source>&amp;Close</source>
        <translation>Tan&amp;ca </translation>
    </message>
    <message>
        <location filename="../main.cpp" line="74"/>
        <location filename="../main.cpp" line="82"/>
        <source>Error</source>
        <translation>Error</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="75"/>
        <source>You seem to be logged in as root, please log out and log in as normal user to use this program.</source>
        <translation>Sembla que esteu connectat com a administrador, si us plau sortiu i connecteu-vos com a usuari normal per a usar aquest programa.</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="83"/>
        <source>You must run this program with admin access.</source>
        <translation>Cal executar aquest programa com a administrador.</translation>
    </message>
    <message>
        <location filename="../service.cpp" line="116"/>
        <source>Could not find service description</source>
        <translation>No he trobat la descripció del servei</translation>
    </message>
</context>
</TS>
